@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2002, 2007, 2008, 2009, 2010, 2011 Free Software
-   Foundation, Inc.
+   Copyright (C) 2002, 2007-2012, 2014-2017 Free Software Foundation,
+   Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -49,6 +49,14 @@
 char *mu_pam_service = PACKAGE;
 
 #ifdef USE_LIBPAM
+static struct mu_cfg_param mu_pam_param[] = {
+  { "service", mu_c_string, &mu_pam_service, 0, NULL,
+    N_("Set PAM service name."),
+    N_("name") },
+  { NULL }
+};
+
+
 #define COPY_STRING(s) (s) ? strdup(s) : NULL
 
 static char *_pwd;
@@ -175,37 +183,13 @@ mu_authenticate_pam (struct mu_auth_data **return_data MU_ARG_UNUSED,
 }
 
 #else
-
-int
-mu_authenticate_pam (struct mu_auth_data **return_data MU_ARG_UNUSED,
-		     const void *key MU_ARG_UNUSED,
-		     void *func_data MU_ARG_UNUSED,
-		     void *call_data MU_ARG_UNUSED)
-{
-  return ENOSYS;
-}
-
+# define mu_pam_param NULL
+# define mu_authenticate_pam NULL
 #endif
 
-int
-mu_pam_module_init (enum mu_gocs_op op, void *data)
-{
-  if (op == mu_gocs_op_set && data)
-    {
-      struct mu_gocs_pam *p = data;
-      mu_pam_service = p->service ? strdup (p->service) : p->service;
-    }
-  return 0;
-}
-
 struct mu_auth_module mu_auth_pam_module = {
-  "pam",
-  mu_pam_module_init,
-  mu_authenticate_pam,
-  NULL,
-  mu_auth_nosupport,
-  NULL,
-  mu_auth_nosupport,
-  NULL
+  .name = "pam",
+  .handler = { [mu_auth_authenticate] = mu_authenticate_pam },
+  .cfg = mu_pam_param
 };
 
